[**@notabene/javascript-sdk**](../../README.md) • **Docs**

***

[@notabene/javascript-sdk](../../modules.md) / [types](../README.md) / ProofTypes

# Enumeration: ProofTypes

Types of ownership proofs supported by the system

## Remarks

Supported proof types:
- SelfDeclaration: User self-declares ownership without cryptographic proof
- EIP191: Ethereum personal signature following EIP-191 standard
- SIWE: Sign-In with Ethereum message signature (EIP-4361)
- EIP712: Ethereum typed data signature following EIP-712 standard
- BIP137: Bitcoin message signature following BIP-137
- XPUB: Extended public key signature for HD wallets
- MicroTransfer: Proof via small blockchain transaction
- Screenshot: Image proof of ownership/access

## See

 - [SignatureProof](../interfaces/SignatureProof.md) For signature-based proofs
 - [DeclarationProof](../interfaces/DeclarationProof.md) For self-declaration proofs
 - [MicroTransferProof](../interfaces/MicroTransferProof.md) For transaction-based proofs
 - [ScreenshotProof](../interfaces/ScreenshotProof.md) For screenshot proofs

## Enumeration Members

### BIP137

> **BIP137**: `"bip-137"`

#### Defined in

[types.ts:1002](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1002)

***

### BIP137\_XPUB

> **BIP137\_XPUB**: `"xpub"`

#### Defined in

[types.ts:1003](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1003)

***

### Connect

> **Connect**: `"connect"`

#### Defined in

[types.ts:1007](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1007)

***

### ED25519

> **ED25519**: `"ed25519"`

#### Defined in

[types.ts:1004](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1004)

***

### EIP1271

> **EIP1271**: `"eip-1271"`

#### Defined in

[types.ts:1001](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1001)

***

### EIP191

> **EIP191**: `"eip-191"`

#### Defined in

[types.ts:999](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L999)

***

### EIP712

> **EIP712**: `"eip-712"`

#### Defined in

[types.ts:1000](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1000)

***

### MicroTransfer

> **MicroTransfer**: `"microtransfer"`

#### Defined in

[types.ts:1005](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1005)

***

### Screenshot

> **Screenshot**: `"screenshot"`

#### Defined in

[types.ts:1006](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1006)

***

### SelfDeclaration

> **SelfDeclaration**: `"self-declaration"`

#### Defined in

[types.ts:996](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L996)

***

### SIWE

> **SIWE**: `"siwe"`

#### Defined in

[types.ts:997](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L997)

***

### SIWX

> **SIWX**: `"siwx"`

#### Defined in

[types.ts:998](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L998)
