[**@notabene/javascript-sdk**](../../README.md) • **Docs**

***

[@notabene/javascript-sdk](../../modules.md) / [types](../README.md) / SignatureProof

# Interface: SignatureProof

Interface for signature-based ownership proofs that use cryptographic message signing

## Remarks

Extends the base OwnershipProface to add signature-specific properties:
- Supports multiple signature standards like EIP-191, EIP-712, BIP-137, SIWE
- Includes the cryptographic proof signature string
- Contains an attestation message that was signed
- Records which wallet provider was used for signing

The signature proves ownership by demonstrating control of the private keys
associated with the claimed address.

## See

 - [ProofTypes](../enumerations/ProofTypes.md) For supported signature types
 - [OwnershipProof](OwnershipProof.md) For base proof properties

## Extends

- [`OwnershipProof`](OwnershipProof.md)

## Properties

### address

> **address**: \`$\{string\}:$\{string\}:$\{string\}\`

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`address`](OwnershipProof.md#address)

#### Defined in

[types.ts:1035](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1035)

***

### attestation

> **attestation**: `string`

#### Defined in

[types.ts:1067](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1067)

***

### did

> **did**: \`did:$\{string\}:$\{string\}\`

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`did`](OwnershipProof.md#did)

#### Defined in

[types.ts:1034](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1034)

***

### proof

> **proof**: `string`

#### Defined in

[types.ts:1066](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1066)

***

### status

> **status**: [`ProofStatus`](../enumerations/ProofStatus.md)

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`status`](OwnershipProof.md#status)

#### Defined in

[types.ts:1033](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1033)

***

### type

> **type**: [`SIWE`](../enumerations/ProofTypes.md#siwe) \| [`SIWX`](../enumerations/ProofTypes.md#siwx) \| [`EIP191`](../enumerations/ProofTypes.md#eip191) \| [`EIP712`](../enumerations/ProofTypes.md#eip712) \| [`EIP1271`](../enumerations/ProofTypes.md#eip1271) \| [`BIP137`](../enumerations/ProofTypes.md#bip137) \| [`BIP137_XPUB`](../enumerations/ProofTypes.md#bip137_xpub) \| [`ED25519`](../enumerations/ProofTypes.md#ed25519)

#### Overrides

[`OwnershipProof`](OwnershipProof.md).[`type`](OwnershipProof.md#type)

#### Defined in

[types.ts:1056](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1056)

***

### wallet\_provider

> **wallet\_provider**: `string`

#### Defined in

[types.ts:1068](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/37b9a143f8fa9e46954aa19cbff9c441035afdce/src/types.ts#L1068)
